---
title: <span class="badge builder"></span> MovingAverageHoltModelSettings
---
# <span class="badge builder"></span> MovingAverageHoltModelSettings

## Constructor

```python
MovingAverageHoltModelSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.MovingAverageHoltModelSettings
```

### <span class="badge object-method"></span> minimize

```python
def minimize(minimize: bool) -> typing.Self
```

### <span class="badge object-method"></span> predict

```python
def predict(predict: str) -> typing.Self
```

### <span class="badge object-method"></span> settings

```python
def settings(settings: cogbuilder.Builder[elasticsearch.ElasticsearchMovingAverageHoltModelSettingsSettings]) -> typing.Self
```

### <span class="badge object-method"></span> window

```python
def window(window: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [MovingAverageHoltModelSettings](./object-MovingAverageHoltModelSettings.md)
